@@ -75,7 +75,7 @@ function uninstall_container_before_upgrade(){
   fi
 }
 
-while getopts "h:U:P:u:p:s:n:F:" opt; do
+while getopts "h:U:P:u:p:sn:F:" opt; do
     case $opt in
         [h])  HOST=$OPTARG;;
         [U])  SUPER_USER_NAME=$OPTARG;;
@@ -97,7 +97,7 @@ fi
 
 if [ -z "$AZURE_DB_NAME" ]; then
   info_log "Check the host $HOST of source database ..."
-  ping -c 1 $HOST >/dev/null 2>&1
+  nc -zv $HOST 5432 >/dev/null 2>&1
   if [ $? -eq 0 ]; then
      echo 
   else
@@ -126,7 +126,7 @@ CURRENT_RETRY_TIMES=0
 STREAMING_CHECK_RETRY_INTERVAL=20
 TIMEOUT_SECONDS_FOR_UPGRADE_JOB=1800
 TIMEOUT_SECONDS_FOR_POD=300
-HELM_REPO_PATH="/opt/cms/charts"
+HELM_REPO_PATH="/opt/cms/charts/"
 CMS_VAR_PATH="/opt/cms/ConfigBundle/products-var.yaml"
 CMS_NAMESPACE=$(cat ${CMS_VAR_PATH}|grep cms_namespace|tr '"' ' '|awk -F ":" '{print $2}'|sed s/[[:space:]]//g)
 if [ $? -ne 0 ]; then 
@@ -173,9 +173,9 @@ fi
 PG_SETUP_CHART_VERSION=""
 function get_pg_setup_chart_version(){
   PG_SETUP_TGZ_FILE=$(ls ${HELM_REPO_PATH}|grep -E 'cms-pg-setup.*tgz')
-  PG_SETUP_CHART_VERSION=$(helm inspect chart ${HELM_REPO_PATH}/${PG_SETUP_TGZ_FILE} | grep '^version:' | awk '{print $2}')
+  PG_SETUP_CHART_VERSION=$(helm inspect chart ${HELM_REPO_PATH}${PG_SETUP_TGZ_FILE} | grep '^version:' | awk '{print $2}')
   if [ $? -ne 0 ]; then
-    error_log "Fail to get cms-pg-setup chart version from ${HELM_REPO_PATH}/${PG_SETUP_TGZ_FILE}"
+    error_log "Fail to get cms-pg-setup chart version from ${HELM_REPO_PATH}${PG_SETUP_TGZ_FILE}"
     exit 1
   fi
 }
@@ -202,7 +202,7 @@ else
   
   info_log "Deploy the Helm Chart to upgrade postgreSQL and migrate database data."
   TGZ_FILE=$(ls ${HELM_REPO_PATH}|grep -E 'cms-container-pg-upgrade.*tgz')
-  helm install cms-container-pg-upgrade --set image.repository=${IMAGE_REGISTRY},db_host=$HOST,db_name=$AZURE_DB_NAME,azuredb=true,epgEnable=$EPG_ENABLE,force_upgrade=$FORCE_UPGRADE,pg_password=$SUPER_USER_PASSWORD,pg_setup_chart_version=${PG_SETUP_CHART_VERSION} -n ${CMS_NAMESPACE} ${HELM_REPO_PATH}/${TGZ_FILE}
+  helm install cms-container-pg-upgrade --set image.repository=${IMAGE_REGISTRY},db_host=$HOST,db_name=$AZURE_DB_NAME,azuredb=true,epgEnable=$EPG_ENABLE,force_upgrade=$FORCE_UPGRADE,pg_password=$SUPER_USER_PASSWORD,pg_setup_chart_version=${PG_SETUP_CHART_VERSION} -n ${CMS_NAMESPACE} ${HELM_REPO_PATH}${TGZ_FILE}
 
   if [ $? -ne 0 ]; then 
     error_log "Deploy the Helm Chart files fail. Please fix the error and execute this script again."
@@ -346,7 +346,7 @@ uninstall_container_before_upgrade
 
 info_log "Deploy the Helm Chart to upgrade postgreSQL and migrate database data."
 TGZ_FILE=$(ls ${HELM_REPO_PATH}|grep -E 'cms-container-pg-upgrade.*tgz')
-helm install cms-container-pg-upgrade --set image.repository=${IMAGE_REGISTRY},epgEnable=$EPG_ENABLE,pg_setup_chart_version=${PG_SETUP_CHART_VERSION} -n ${CMS_NAMESPACE} ${HELM_REPO_PATH}/${TGZ_FILE}
+helm install cms-container-pg-upgrade --set image.repository=${IMAGE_REGISTRY},epgEnable=$EPG_ENABLE,pg_setup_chart_version=${PG_SETUP_CHART_VERSION} -n ${CMS_NAMESPACE} ${HELM_REPO_PATH}${TGZ_FILE}
 if [ $? -ne 0 ]; then 
     error_log "Deploy the Helm Chart files fail. Please fix the error and execute this script again."
     exit 1
@@ -370,7 +370,7 @@ done
 info_log "Starting the cms-pg-workflow service..."
 PGTGZ_FILE=$(ls -lt ${HELM_REPO_PATH} |grep -E 'cms-postgresql-12.3.0-.+tgz' |head -n 1 | awk '{print $9}')
 WF_PGVALUES_FILE=$(ls -lt /opt/cms/charts/values | grep -P 'values_cms-pg-workflow_12.3.0-.+yaml' | head -n 1 | awk '{print $9}')
-helm upgrade --install -n ${CMS_NAMESPACE} cms-pg-workflow --set wfskeeper.replicaCount=1 --values=/opt/cms/charts/values/$WF_PGVALUES_FILE  ${HELM_REPO_PATH}/$PGTGZ_FILE --no-hooks
+helm upgrade --install -n ${CMS_NAMESPACE} cms-pg-workflow --set wfskeeper.replicaCount=1 --values=/opt/cms/charts/values/$WF_PGVALUES_FILE  ${HELM_REPO_PATH}$PGTGZ_FILE --no-hooks
 if [ $? -ne 0 ]; then 
     error_log "Starting cms-pg-workflow service failed."
     exit 1
@@ -379,7 +379,7 @@ fi
 if [ "$EPG_ENABLE" = true ]; then
   info_log "Starting the cms-pg-epg service..."
   EPG_PGVALUES_FILE=$(ls -lt /opt/cms/charts/values | grep -P 'values_cms-pg-epg_12.3.0-.+yaml' | head -n 1 | awk '{print $9}')
-  helm upgrade --install -n ${CMS_NAMESPACE} cms-pg-epg --set epgkeeper.replicaCount=1 --values=/opt/cms/charts/values/$EPG_PGVALUES_FILE  ${HELM_REPO_PATH}/$PGTGZ_FILE --no-hooks
+  helm upgrade --install -n ${CMS_NAMESPACE} cms-pg-epg --set epgkeeper.replicaCount=1 --values=/opt/cms/charts/values/$EPG_PGVALUES_FILE  ${HELM_REPO_PATH}$PGTGZ_FILE --no-hooks
   if [ $? -ne 0 ]; then 
     error_log "Starting the cms-pg-epg service failed."
     exit 1
@@ -388,7 +388,7 @@ fi
 
 info_log "Starting the cms-pg-metadata-manager service..."  
 MM_PGVALUES_FILE=$(ls -lt /opt/cms/charts/values | grep -P 'values_cms-pg-metadata-manager_12.3.0-.+yaml' | head -n 1 | awk '{print $9}')
-helm upgrade --install -n ${CMS_NAMESPACE} cms-pg-metadata-manager --set cmskeeper.replicaCount=1 --values=/opt/cms/charts/values/$MM_PGVALUES_FILE  ${HELM_REPO_PATH}/$PGTGZ_FILE --no-hooks
+helm upgrade --install -n ${CMS_NAMESPACE} cms-pg-metadata-manager --set cmskeeper.replicaCount=1 --values=/opt/cms/charts/values/$MM_PGVALUES_FILE  ${HELM_REPO_PATH}$PGTGZ_FILE --no-hooks
 if [ $? -ne 0 ]; then 
     error_log "Starting the cms-pg-metadata-manager service failed."
     exit 1
